@@ -66,6 +66,7 @@ class AuditlogModelRegistry:
         exclude_fields: Optional[list[str]] = None,
         mapping_fields: Optional[dict[str, str]] = None,
         mask_fields: Optional[list[str]] = None,
+        mask_callable: Optional[str] = None,
         m2m_fields: Optional[Collection[str]] = None,
         serialize_data: bool = False,
         serialize_kwargs: Optional[dict[str, Any]] = None,
@@ -79,6 +80,8 @@ class AuditlogModelRegistry:
         :param exclude_fields: The fields to exclude. Overrides the fields to include.
         :param mapping_fields: Mapping from field names to strings in diff.
         :param mask_fields: The fields to mask for sensitive info.
+        :param mask_callable: The dotted path to a callable that will be used for masking. If not provided,
+                              the default mask_callable will be used.
         :param m2m_fields: The fields to handle as many to many.
         :param serialize_data: Option to include a dictionary of the objects state in the auditlog.
         :param serialize_kwargs: Optional kwargs to pass to Django serializer
@@ -120,6 +123,7 @@ class AuditlogModelRegistry:
                 "exclude_fields": exclude_fields,
                 "mapping_fields": mapping_fields,
                 "mask_fields": mask_fields,
+                "mask_callable": mask_callable,
                 "m2m_fields": m2m_fields,
                 "serialize_data": serialize_data,
                 "serialize_kwargs": serialize_kwargs,
@@ -172,6 +176,7 @@ class AuditlogModelRegistry:
             "exclude_fields": list(self._registry[model]["exclude_fields"]),
             "mapping_fields": dict(self._registry[model]["mapping_fields"]),
             "mask_fields": list(self._registry[model]["mask_fields"]),
+            "mask_callable": self._registry[model]["mask_callable"],
         }
 
     def get_serialize_options(self, model: ModelBase):
@@ -371,6 +376,9 @@ class AuditlogModelRegistry:
                     model=model, m2m_fields=m2m_fields, exclude_fields=exclude_fields
                 )
 
+        if not isinstance(settings.AUDITLOG_STORE_JSON_CHANGES, bool):
+            raise TypeError("Setting 'AUDITLOG_STORE_JSON_CHANGES' must be a boolean")
+
         self._register_models(settings.AUDITLOG_INCLUDE_TRACKING_MODELS)
 
 
